@@ -2,13 +2,23 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: MittelmannBndryCntrlDiri.cpp 1864 2010-12-22 19:21:02Z andreasw $
+// $Id: MittelmannBndryCntrlDiri.cpp 2005 2011-06-06 12:55:16Z stefan $
 //
 // Authors:  Andreas Waechter             IBM    2005-10-18
 //                  based on MyNLP.cpp
 
 #include "MittelmannBndryCntrlDiri.hpp"
 
+#ifdef HAVE_CASSERT
+# include <cassert>
+#else
+# ifdef HAVE_ASSERT_H
+#  include <assert.h>
+# else
+#  error "don't have header file for assert"
+# endif
+#endif
+
 using namespace Ipopt;
 
 /* Constructor. */
