@@ -2,7 +2,7 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpInexactAlgBuilder.cpp 1864 2010-12-22 19:21:02Z andreasw $
+// $Id: IpInexactAlgBuilder.cpp 2008 2011-06-11 16:23:59Z stefan $
 //
 // Authors:  Andreas Waechter     IBM                  2008-09-05
 //            based on IpAlgBuilder.cpp (rev 1311)
@@ -45,6 +45,10 @@
 #include "IpInexactNormalTerminationTester.hpp"
 #include "IpInexactPDTerminationTester.hpp"
 
+#ifdef COIN_HAS_HSL
+# include "CoinHslConfig.h"
+#endif
+
 #ifdef HAVE_WSMP
 # include "IpWsmpSolverInterface.hpp"
 #endif
@@ -123,7 +127,7 @@ namespace Ipopt
     std::string linear_solver;
     options.GetStringValue("linear_solver", linear_solver, prefix);
     if (linear_solver=="ma27") {
-#ifndef HAVE_MA27
+#ifndef COINHSL_HAS_MA27
 # ifdef HAVE_LINEARSOLVERLOADER
       SolverInterface = new Ma27TSolverInterface();
       char buf[256];
@@ -145,7 +149,7 @@ namespace Ipopt
 
     }
     else if (linear_solver=="ma57") {
-#ifndef HAVE_MA57
+#ifndef COINHSL_HAS_MA57
 # ifdef HAVE_LINEARSOLVERLOADER
       SolverInterface = new Ma57TSolverInterface();
       char buf[256];
