@@ -2,7 +2,7 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpInexactPDTerminationTester.cpp 2051 2011-09-20 12:39:11Z stefan $
+// $Id: IpInexactPDTerminationTester.cpp 2073 2012-02-12 15:54:34Z stefan $
 //
 // Authors:  Andreas Waechter            IBM    2008-09-19
 
@@ -400,7 +400,7 @@ namespace Ipopt
       Jnlst().Printf(J_MOREDETAILED, J_LINEAR_ALGEBRA, "TT: Nu = ||A*u||^2/||A||^2 = %23.16e\n", Nu);
 
       // Compute Upsilon = ||u||^2 - Nu
-      Upsilon = u_norm_scaled - Nu;
+      Upsilon = u_norm_scaled*u_norm_scaled - Nu;
       Jnlst().Printf(J_MOREDETAILED, J_LINEAR_ALGEBRA, "TT: Upsilon = ||u||^2 - ||A*u||^2/||A||^2 = %23.16e\n", Upsilon);
     }
 
