@@ -1,8 +1,8 @@
-// Copyright (C) 2004, 2009 International Business Machines and others.
+// Copyright (C) 2004, 2011 International Business Machines and others.
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpAlgBuilder.cpp 1864 2010-12-22 19:21:02Z andreasw $
+// $Id: IpAlgBuilder.cpp 2028 2011-06-30 18:32:37Z andreasw $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2004-09-29
 
@@ -52,9 +52,13 @@
 #include "IpEquilibrationScaling.hpp"
 #include "IpExactHessianUpdater.hpp"
 
+#ifdef COIN_HAS_HSL
+#include "CoinHslConfig.h"
+#endif
 #include "IpMa27TSolverInterface.hpp"
 #include "IpMa57TSolverInterface.hpp"
 #include "IpMa77SolverInterface.hpp"
+#include "IpMa86SolverInterface.hpp"
 #include "IpMc19TSymScalingMethod.hpp"
 #include "IpPardisoSolverInterface.hpp"
 #include "IpSlackBasedTSymScalingMethod.hpp"
@@ -133,25 +137,29 @@ namespace Ipopt
   void AlgorithmBuilder::RegisterOptions(SmartPtr<RegisteredOptions> roptions)
   {
     roptions->SetRegisteringCategory("Linear Solver");
-    roptions->AddStringOption7(
+    roptions->AddStringOption8(
       "linear_solver",
       "Linear solver used for step computations.",
-#ifdef HAVE_MA27
+#ifdef COINHSL_HAS_MA27
       "ma27",
 #else
-# ifdef HAVE_MA57
+# ifdef COINHSL_HAS_MA57
       "ma57",
 # else
-#  ifdef HAVE_PARDISO
-      "pardiso",
+#  ifdef COINHSL_HAS_MA86
+      "ma86",
 #  else
-#   ifdef HAVE_WSMP
-      "wsmp",
+#   ifdef HAVE_PARDISO
+      "pardiso",
 #   else
-#    ifdef COIN_HAS_MUMPS
-      "mumps",
+#    ifdef HAVE_WSMP
+      "wsmp",
 #    else
+#     ifdef COIN_HAS_MUMPS
+      "mumps",
+#     else
       "ma27",
+#     endif
 #    endif
 #   endif
 #  endif
@@ -159,7 +167,8 @@ namespace Ipopt
 #endif
       "ma27", "use the Harwell routine MA27",
       "ma57", "use the Harwell routine MA57",
-      "ma77", "use the Harwell routine MA77",
+      "ma77", "use the Harwell routine HSL_MA77",
+      "ma86", "use the Harwell routine HSL_MA86",
       "pardiso", "use the Pardiso package",
       "wsmp", "use WSMP package",
       "mumps", "use MUMPS package",
@@ -174,7 +183,7 @@ namespace Ipopt
     roptions->AddStringOption3(
       "linear_system_scaling",
       "Method for scaling the linear system.",
-#ifdef HAVE_MC19
+#ifdef COINHSL_HAS_MC19
       "mc19",
 #else
       "none",
@@ -243,7 +252,7 @@ namespace Ipopt
       "extended", "use an extended augmented system",
       "");
 
-    roptions->SetRegisteringCategory("Undocumented");
+    roptions->SetRegisteringCategory("Line Search");
     roptions->AddStringOption3(
       "line_search_method",
       "Globalization method used in backtracking line search",
@@ -251,7 +260,9 @@ namespace Ipopt
       "filter", "Filter method",
       "cg-penalty", "Chen-Goldfarb penalty function",
       "penalty", "Standard penalty function",
-      "");
+      "Only the \"filter\" choice is officially supported.  But sometimes, "
+      "good results might be obtained with the other choices.");
+    roptions->SetRegisteringCategory("Undocumented");
     roptions->AddStringOption2(
       "wsmp_iterative",
       "Switches to iterative solver in WSMP.",
@@ -283,7 +294,7 @@ namespace Ipopt
     options.GetStringValue("linear_solver", linear_solver, prefix);
     bool use_custom_solver = false;
     if (linear_solver=="ma27") {
-#ifndef HAVE_MA27
+#ifndef COINHSL_HAS_MA27
 # ifdef HAVE_LINEARSOLVERLOADER
       SolverInterface = new Ma27TSolverInterface();
       char buf[256];
@@ -305,7 +316,7 @@ namespace Ipopt
 
     }
     else if (linear_solver=="ma57") {
-#ifndef HAVE_MA57
+#ifndef COINHSL_HAS_MA57
 # ifdef HAVE_LINEARSOLVERLOADER
       SolverInterface = new Ma57TSolverInterface();
       char buf[256];
@@ -327,11 +338,33 @@ namespace Ipopt
 
     }
     else if (linear_solver=="ma77") {
-#ifndef HAVE_MA77
+#ifndef COINHSL_HAS_MA77
       THROW_EXCEPTION(OPTION_INVALID, "Support for MA77 has not been compiled into Ipopt.");
 #else
       SolverInterface = new Ma77SolverInterface();
 #endif
+    }
+    else if (linear_solver=="ma86") {
+#ifndef COINHSL_HAS_MA86
+# ifdef HAVE_LINEARSOLVERLOADER
+      SolverInterface = new Ma86SolverInterface();
+      char buf[256];
+      int rc = LSL_loadHSL(NULL, buf, 255);
+      if (rc) {
+        std::string errmsg;
+        errmsg = "Selected linear solver HSL_MA86 not available.\nTried to obtain HSL_MA86 from shared library \"";
+        errmsg += LSL_HSLLibraryName();
+        errmsg += "\", but the following error occured:\n";
+        errmsg += buf;
+        THROW_EXCEPTION(OPTION_INVALID, errmsg.c_str());
+      }
+# else
+      THROW_EXCEPTION(OPTION_INVALID, "Support for HSL_MA86 has not been compiled into Ipopt.");
+# endif
+#else
+      SolverInterface = new Ma86SolverInterface();
+#endif
+
     }
     else if (linear_solver=="pardiso") {
 #ifndef HAVE_PARDISO
@@ -403,7 +436,7 @@ namespace Ipopt
         }
       }
       if (linear_system_scaling=="mc19") {
-#ifndef HAVE_MC19
+#ifndef COINHSL_HAS_MC19
 # ifdef HAVE_LINEARSOLVERLOADER
         ScalingMethod = new Mc19TSymScalingMethod();
         char buf[256];
