@@ -2,13 +2,18 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpEquilibrationScaling.cpp 1864 2010-12-22 19:21:02Z andreasw $
+// $Id: IpEquilibrationScaling.cpp 2008 2011-06-11 16:23:59Z stefan $
 //
 // Authors:  Andreas Waechter            IBM    2007-05-21
 
+#include "IpoptConfig.h"
 #include "IpEquilibrationScaling.hpp"
 #include "IpTripletHelper.hpp"
 
+#ifdef COIN_HAS_HSL
+#include "CoinHslConfig.h"
+#endif
+
 #ifdef HAVE_CMATH
 # include <cmath>
 #else
@@ -186,7 +191,7 @@ namespace Ipopt
     float* R = new float[N];
     float* C = new float[N];
     float* W = new float[5*N];
-#ifdef HAVE_MC19
+#ifdef COINHSL_HAS_MC19
     const ipfint NZ = nnz_jac_c+nnz_jac_d+nnz_grad_f;
     //F77_FUNC(mc19ad,MC19AD)(&N, &NZ, avrg_values, AIRN, AJCN, R, C, W);
     F77_FUNC(mc19ad,MC19AD)(&N, &NZ, avrg_values, AJCN, AIRN, C, R, W);
