@@ -1,8 +1,8 @@
-// Copyright (C) 2004, 2006 International Business Machines and others.
+// Copyright (C) 2004, 2011 International Business Machines and others.
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpOrigIterationOutput.hpp 1864 2010-12-22 19:21:02Z andreasw $
+// $Id: IpOrigIterationOutput.hpp 2020 2011-06-16 20:46:16Z andreasw $
 //
 // Authors:  Andreas Waechter, Carl Laird       IBM    2004-09-27
 
@@ -59,6 +59,9 @@ namespace Ipopt
     /** Flag indicating weather info string should be printed at end
      *  of iteration summary line. */
     bool print_info_string_;
+
+    /** Option indication what should be printed in inf_pr column */
+    InfPrOutput inf_pr_output_;
   };
 
 } // namespace Ipopt
