@@ -2,7 +2,7 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpRestoIterationOutput.hpp 1864 2010-12-22 19:21:02Z andreasw $
+// $Id: IpRestoIterationOutput.hpp 2020 2011-06-16 20:46:16Z andreasw $
 //
 // Authors:  Carl Laird, Andreas Waechter       IBM    2004-09-27
 
@@ -66,6 +66,9 @@ namespace Ipopt
     /** Flag indicating weather info string should be printed at end
      *  of iteration summary line. */
     bool print_info_string_;
+
+    /** Option indication what should be printed in inf_pr column */
+    InfPrOutput inf_pr_output_;
   };
 
 } // namespace Ipopt
