@@ -1,12 +1,20 @@
 // Copyright (C) 2004, 2010 International Business Machines and others.
 // All Rights Reserved.
-// This code is published under the Common Public License.
+// This code is published under the Eclipse Public License.
 //
-// $Id: IpMa27TSolverInterface.cpp 1692 2010-06-21 19:10:07Z andreasw $
+// $Id: IpMa27TSolverInterface.cpp 2008 2011-06-11 16:23:59Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2005-03-17
 
 #include "IpoptConfig.h"
+
+#ifdef COIN_HAS_HSL
+#include "CoinHslConfig.h"
+#endif
+
+// if we do not have MA27 in HSL or the linear solver loader, then we want to build the MA27 interface
+#if defined(COINHSL_HAS_MA27) || defined(HAVE_LINEARSOLVERLOADER)
+
 #include "IpMa27TSolverInterface.hpp"
 
 #ifdef HAVE_CMATH
@@ -605,3 +613,5 @@ namespace Ipopt
   }
 
 } // namespace Ipopt
+
+#endif /* COINHSL_HAS_MA27 or HAVE_LINEARSOLVERLOADER */
