@@ -2,12 +2,20 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpMa57TSolverInterface.cpp 1864 2010-12-22 19:21:02Z andreasw $
+// $Id: IpMa57TSolverInterface.cpp 2008 2011-06-11 16:23:59Z stefan $
 //
 // Authors:  Michael Hagemann               Univ of Basel 2005-10-28
 //               original version (based on MA27TSolverInterface.cpp)
 
 #include "IpoptConfig.h"
+
+#ifdef COIN_HAS_HSL
+#include "CoinHslConfig.h"
+#endif
+
+// if we do not have MA57 in HSL or the linear solver loader, then we want to build the MA57 interface
+#if defined(COINHSL_HAS_MA57) || defined(HAVE_LINEARSOLVERLOADER)
+
 #include "IpMa57TSolverInterface.hpp"
 
 #ifdef HAVE_CMATH
@@ -792,3 +800,5 @@ namespace Ipopt
   }
 
 } // namespace Ipopt
+
+#endif /* COINHSL_HAS_MA57 or HAVE_LINEARSOLVERLOADER */
