@@ -3,11 +3,19 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpMa77SolverInterface.cpp 1864 2010-12-22 19:21:02Z andreasw $
+// $Id: IpMa77SolverInterface.cpp 2010 2011-06-11 16:37:45Z stefan $
 //
 // Authors: Jonathan Hogg                           2009-07-29 
 //          Carl Laird, Andreas Waechter     IBM    2004-03-17
 
+#include "IpoptConfig.h"
+
+#ifdef COIN_HAS_HSL
+#include "CoinHslConfig.h"
+#endif
+
+#ifdef COINHSL_HAS_MA77
+
 #include "IpMa77SolverInterface.hpp"
 #include <iostream>
 using namespace std;
@@ -306,3 +314,4 @@ void Ma77SolverInterface::MetisOrder(const int ndim, const Index *ptr,
 
 } // namespace Ipopt
 
+#endif /* COINHSL_HAS_MA77 */
