@@ -73,6 +73,9 @@ namespace Ipopt
     mumps_->sym = 2;//general symetric matrix
     mumps_->comm_fortran = USE_COMM_WORLD;
     dmumps_c(mumps_);
+    mumps_->icntl[1] = 0;
+    mumps_->icntl[2] = 0;//QUIETLY!
+    mumps_->icntl[3] = 0;
     mumps_ptr_ = (void*)mumps_;
   }
 
@@ -317,10 +320,6 @@ namespace Ipopt
 
     mumps_data->job = 1;//symbolic ordering pass
 
-    mumps_data->icntl[1] = 0;
-    mumps_data->icntl[2] = 0;//QUIETLY!
-    mumps_data->icntl[3] = 0;
-
     //mumps_data->icntl[1] = 6;
     //mumps_data->icntl[2] = 6;//QUIETLY!
     //mumps_data->icntl[3] = 4;
@@ -435,8 +434,8 @@ namespace Ipopt
 
     if (error == -13) {
       Jnlst().Printf(J_ERROR, J_LINEAR_ALGEBRA,
-                     "MUMPS returned INFO(1) =%d - out or memory.\nIn some cases it helps to decrease the value of the option \"mumps_mem_percent\".\n",
-                     error);
+                     "MUMPS returned INFO(1) =%d - out of memory when trying to allocate %d %s.\nIn some cases it helps to decrease the value of the option \"mumps_mem_percent\".\n",
+                     error, mumps_data->info[1] < 0 ? -mumps_data->info[1] : mumps_data->info[1], mumps_data->info[1] < 0 ? "MB" : "bytes");
       return SYMSOLVER_FATAL_ERROR;
     }
     if (error < 0) {//some other error
