@@ -2,7 +2,7 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpJournalist.hpp 1864 2010-12-22 19:21:02Z andreasw $
+// $Id: IpJournalist.hpp 2044 2011-08-27 11:21:16Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2004-08-13
 
@@ -20,7 +20,17 @@
 # ifdef HAVE_STDARG_H
 #  include <stdarg.h>
 # else
-#  error "don't have header file for stdarg"
+#  include <cstdarg>  // if this header is included by someone who does not define HAVE_CSTDARG or HAVE_STDARG, let's hope that cstdarg is available
+# endif
+#endif
+
+#ifdef HAVE_CSTDIO
+# include <cstdio>
+#else
+# ifdef HAVE_STDIO_H
+#  include <stdio.h>
+# else
+#  include <cstdio>  // if this header is included by someone who does not define HAVE_CSTDIO or HAVE_STDIO, let's hope that cstdio is available
 # endif
 #endif
 
